@@ -3,9 +3,9 @@ package Sah::Schema::dirname::unix;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-29'; # DATE
+our $DATE = '2023-11-18'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.022'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem directory name on a Unix system',
@@ -49,7 +49,7 @@ Sah::Schema::dirname::unix - Filesystem directory name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.022 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
+This document describes version 0.023 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
 
 =head1 SYNOPSIS
 
@@ -83,11 +83,11 @@ valid, a non-empty error message otherwise):
  my $errmsg = $validator->($data);
  
  # a sample valid data
- $data = "foo//bar";
+ $data = "/";
  my $errmsg = $validator->($data); # => ""
  
  # a sample invalid data
- $data = "";
+ $data = "foo\0";
  my $errmsg = $validator->($data); # => "Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z"
 
 Often a schema has coercion rule or default value rules, so after validation the
@@ -98,12 +98,12 @@ validated value will be different from the original. To return the validated
  my $res = $validator->($data); # [$errmsg, $validated_val]
  
  # a sample valid data
- $data = "foo//bar";
- my $res = $validator->($data); # => ["","foo/bar"]
+ $data = "/";
+ my $res = $validator->($data); # => ["","/"]
  
  # a sample invalid data
- $data = "";
- my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z",""]
+ $data = "foo\0";
+ my $res = $validator->($data); # => ["Must match regex pattern \\A(?:/|/?(?:[^/\\0]{1,255})(?:/[^/\\0]{1,255})*)\\z","foo\0"]
 
 Data::Sah can also create validator that returns a hash of detailed error
 message. Data::Sah can even create validator that targets other language, like
