@@ -3,9 +3,9 @@ package Sah::Schemas::Path;
 use strict;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2023-10-29'; # DATE
+our $DATE = '2023-11-18'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.022'; # VERSION
+our $VERSION = '0.023'; # VERSION
 
 1;
 # ABSTRACT: Schemas related to filesystem path
@@ -22,7 +22,7 @@ Sah::Schemas::Path - Schemas related to filesystem path
 
 =head1 VERSION
 
-This document describes version 0.022 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-10-29.
+This document describes version 0.023 of Sah::Schemas::Path (from Perl distribution Sah-Schemas-Path), released on 2023-11-18.
 
 =head1 DESCRIPTION
 
@@ -79,10 +79,9 @@ rule. This schema's completion by default only includes directories.
 Directory name, default to current directory.
 
 Note: be careful when using this schema for actions that are destructive,
-because a user can perform those actions without giving an argument (e.g. a
-C<delete-files-in> script). It is safer to use this schema to perform a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by
-default.
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-files-in> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::default_curdir_abs|Sah::Schema::dirname::default_curdir_abs>
@@ -90,10 +89,9 @@ default.
 Directory name, default to current directory (absolutified).
 
 Note: be careful when using this schema for actions that are destructive,
-because a user can perform those actions without giving an argument (e.g. a
-C<delete-files-in> script). It is safer to use this schema to perform a
-non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by
-default.
+because a user can perform those actions without giving an argument (e.g. in a
+C<delete-files-in> script). It is safer to use this schema when performing a
+non=destructive action (e.g. C<ls>) and/or operate in dry-run mode by default.
 
 
 =item * L<dirname::exists|Sah::Schema::dirname::exists>
@@ -121,6 +119,15 @@ This is like the C<dirname> schema but with extra checks relevant to the Unix,
 multipile consecutive slashes C<//> will be normalized into a single one C</>).
 
 
+=item * L<dirname::unix::basename|Sah::Schema::dirname::unix::basename>
+
+Filesystem base directory name on a Unix system.
+
+This is like the C<dirname::unix> schema but not allowing parent directory parts.
+Difference with C<filename::unix::basename> and C<pathname::unix::basename>: the
+completion rule.
+
+
 =item * L<dirname::unix::exists|Sah::Schema::dirname::unix::exists>
 
 Unix directory name, must exist on filesystem.
@@ -185,6 +192,15 @@ This is like the C<filename> schema but with extra checks relevant to the Unix,
 multipile consecutive slashes C<//> will be normalized into a single one C</>).
 
 
+=item * L<filename::unix::basename|Sah::Schema::filename::unix::basename>
+
+Filesystem base file name on a Unix system.
+
+This is like the C<filename::unix> schema but not allowing directory parts.
+Difference with C<dirname::unix::basename> and C<pathname::unix::basename>: the
+completion rule.
+
+
 =item * L<filename::unix::exists|Sah::Schema::filename::unix::exists>
 
 Unix file name, must exist on filesystem.
@@ -257,6 +273,15 @@ This is like the C<pathname> schema but with extra checks relevant to the Unix,
 multipile consecutive slashes C<//> will be normalized into a single one C</>).
 
 
+=item * L<pathname::unix::basename|Sah::Schema::pathname::unix::basename>
+
+Filesystem base path name on a Unix system.
+
+This is like the C<filename::unix> schema but not allowing directory parts.
+Difference with C<dirname::unix::basename> and C<filename::unix::basename>: the
+completion rule.
+
+
 =item * L<pathname::unix::exists|Sah::Schema::pathname::unix::exists>
 
 Unix path name, must exist on filesystem.
